@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: trifecta
 version: 1.5.2
-id: trifecta-1.5.2-b125d0d790a888653ef25b262dc80aeb
-key: trife_LSZKtdxD0IK9vhfGCArczK
+id: trifecta-1.5.2-d68d0d1e7b3496d83e34c521f475c3b5
+key: trife_48U0rXNc4Y8KPfvzqYSRO1
 license: BSD3
 copyright: Copyright (C) 2010-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
-hs-libraries: HStrifecta-1.5.2-LSZKtdxD0IK9vhfGCArczK
+hs-libraries: HStrifecta-1.5.2-48U0rXNc4Y8KPfvzqYSRO1
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
@@ -38,17 +38,17 @@ depends:
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
-    comonad-5-3b2e208311908bc5a9db1ceb26126917
+    comonad-5-eb230ef163a26fe6410daceeb92d736a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    lens-4.13.2.1-51cb0aae339c8977636563c0e1cbdfa1
+    lens-4.13.2.1-e19d77b9fe276f1aacdf6ec68343ec35
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     parsers-0.12.3-1e35467efed8fe38d8f3b579df5912e3
-    profunctors-5.2-026a1eb9905bccdb097d36481584da83
-    reducers-3.12.1-f0d1b50cfbdb1add57ff9cbb6041f153
+    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
+    reducers-3.12.1-945b6d2d7be706517694521697039a82
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
